==> aes_cipher-1.0.0.tar.gz: aes_cipher-1.0.0/aes_cipher/aes_const.py <==
# Copyright (c) 2021 Emanuele Bellocchia
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#
# Imports
#
from Crypto.Cipher import AES


#
# Classes
#

# AES constants class
class AesConst:
    # Get block size
    @staticmethod
    def BlockSize():
        return AES.block_size

    # Get pad size
    @staticmethod
    def PadSize():
        return AesConst.BlockSize()

    # Get key size
    @staticmethod
    def KeySize():
        return AesConst.BlockSize() * 2

    # Get IV size
    @staticmethod
    def IvSize():
        return AesConst.BlockSize()

==> aes_cipher-1.0.1.tar.gz: aes_cipher-1.0.1/aes_cipher/aes_const.py <==
# Copyright (c) 2021 Emanuele Bellocchia
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

#
# Imports
#
from Crypto.Cipher import AES


#
# Classes
#

# AES constants class
class AesConst:
    # Get block size
    @staticmethod
    def BlockSize() -> int:
        return AES.block_size

    # Get pad size
    @staticmethod
    def PadSize() -> int:
        return AesConst.BlockSize()

    # Get key size
    @staticmethod
    def KeySize() -> int:
        return AesConst.BlockSize() * 2

    # Get IV size
    @staticmethod
    def IvSize() -> int:
        return AesConst.BlockSize()
